Clazz.declarePackage("J.api");
(function(){
var c$ = Clazz.declareInterface(J.api, "JmolGestureServerInterface");
})();
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
